==> python_docx_oss-0.0.11.tar.gz: python_docx_oss-0.0.11/README.md <==
<p align="center">
<img src="https://raw.githubusercontent.com/lsaint/python-docx-oss/master/docs/_static/img/oss.png" width="400" alt="oss"/>
</p>

_As a Brazilian jiu-jitsu player, OSS means anything and everything. It's a term used in BJJ that is a way of greeting and demonstrating respect to others._

**_python-docx-oss_** is a Python library for CRUD Microsoft Word (.docx) files. It fork from [python-docx](https://github.com/python-openxml/python-docx).

<p>
    <a href="https://pypi.org/project/python-docx-oss/"><img alt="PyPI" src="https://img.shields.io/pypi/v/python-docx-oss"></a>
    <a href="https://pypi.org/project/python-docx-oss"> <img src="https://img.shields.io/pypi/pyversions/python-docx-oss.svg"/></a>
    <a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
    <a href="https://github.com/lsaint/python-docx-oss/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/badge/License-MIT-yellow.svg"></a>
</p>

______________________________________________________________________

### FAQ

**Q: What's New?**

**A:** [HISTORY](https://github.com/lsaint/python-docx-oss/blob/master/HISTORY.md)

______________________________________________________________________

More information is available in the [python-docx-oss documentation](https://python-docx-oss.readthedocs.io/en/latest/)

This project is based on the original work by [Steve Canny](https://github.com/scanny) and has been modified by [Ethan St. Lee](https://github.com/lsaint).

### Donation

[https://lsaint.github.io/donation/](https://lsaint.github.io/donation/)

==> python_docx_oss-0.1.0rc1.tar.gz: python_docx_oss-0.1.0rc1/README.md <==
<p align="center">
<img src="https://raw.githubusercontent.com/lsaint/python-docx-oss/master/docs/_static/img/oss.png" width="400" alt="oss"/>
</p>

_As a Brazilian jiu-jitsu player, OSS means anything and everything. It's a term used in BJJ that is a way of greeting and demonstrating respect to others._

**_python-docx-oss_** is a Python library for CRUD Microsoft Word (.docx) files. It fork from [python-docx](https://github.com/python-openxml/python-docx).

<p>
    <a href="https://pypi.org/project/python-docx-oss/"><img alt="PyPI" src="https://img.shields.io/pypi/v/python-docx-oss"></a>
    <a href="https://pypi.org/project/python-docx-oss"> <img src="https://img.shields.io/pypi/pyversions/python-docx-oss.svg"/></a>
    <a href="https://github.com/astral-sh/ruff"><img alt="Code style: ruff" src="https://img.shields.io/badge/code%20style-ruff-FF6B6B.svg?logo=ruff&logoColor=white"></a>
    <a href="https://github.com/lsaint/python-docx-oss/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/badge/License-MIT-yellow.svg"></a>
</p>

______________________________________________________________________

### FAQ

**Q: What's New?**

**A:** [HISTORY](https://github.com/lsaint/python-docx-oss/blob/master/HISTORY.md)

______________________________________________________________________

More information is available in the [python-docx-oss documentation](https://python-docx-oss.readthedocs.io/en/latest/)

This project is based on the original work by [Steve Canny](https://github.com/scanny) and has been modified by [Ethan St. Lee](https://github.com/lsaint).

### Donation

[https://lsaint.github.io/donation/](https://lsaint.github.io/donation/)
